import { sendUnaryData as sUD, Server, ServerUnaryCall as SUC } from "@grpc/grpc-js";
import { CacheFileRequest, Empty, ExecuteStepRequest, ExecutionEndingRequest, ExecutionStartingRequest, ExecutionStatusResponse as ESR, FileDiff, ImplementationFileGlobPatternResponse as IFGPR, ImplementationFileListResponse as IFLR, KillProcessRequest, RefactorRequest, RefactorResponse, ScenarioDataStoreInitRequest as SCDSIR, ScenarioExecutionEndingRequest as SCEER, ScenarioExecutionStartingRequest as SCESR, SpecDataStoreInitRequest as SPDSIR, SpecExecutionEndingRequest as SPEER, SpecExecutionStartingRequest as SPESR, StepExecutionEndingRequest as STEER, StepExecutionStartingRequest as STESR, StepNameRequest, StepNameResponse, StepNamesRequest, StepNamesResponse, StepPositionsRequest, StepPositionsResponse, StepValidateRequest, StepValidateResponse, StubImplementationCodeRequest, SuiteDataStoreInitRequest } from "./gen/messages_pb";
import { IRunnerServer } from "./gen/services_grpc_pb";
import { StaticLoader } from "./loaders/StaticLoader";
export declare class RunnerServiceImpl implements IRunnerServer {
    private readonly _server;
    private readonly _loader;
    private _stepValidateRequestProcessor;
    private _stepNameRequestProcessor;
    private _refactorRequestProcessor;
    private _cacheFileRequestProcessor;
    private _stubImplementationCodeRequestProcessor;
    private _stepPositionsRequestProcessor;
    private _executionStartingProcessor;
    private _executionEndingProcessor;
    private _specExecutionStartingProcessor;
    private _specExecutionEndingProcessor;
    private _scenarioExecutionStartingProcessor;
    private _scenarioExecutionEndingProcessor;
    private _stepExecutionStartingProcessor;
    private _stepExecutionEndingProcessor;
    private _executeStepProcessor;
    constructor(server: Server, loader: StaticLoader);
    validateStep(call: SUC<StepValidateRequest, StepValidateResponse>, callback: sUD<StepValidateResponse>): void;
    initializeSuiteDataStore(call: SUC<SuiteDataStoreInitRequest, ESR>, callback: sUD<ESR>): void;
    startExecution(call: SUC<ExecutionStartingRequest, ESR>, callback: sUD<ESR>): void;
    initializeSpecDataStore(call: SUC<SPDSIR, ESR>, callback: sUD<ESR>): void;
    startSpecExecution(call: SUC<SPESR, ESR>, callback: sUD<ESR>): void;
    initializeScenarioDataStore(call: SUC<SCDSIR, ESR>, callback: sUD<ESR>): void;
    startScenarioExecution(call: SUC<SCESR, ESR>, callback: sUD<ESR>): void;
    startStepExecution(call: SUC<STESR, ESR>, callback: sUD<ESR>): void;
    executeStep(call: SUC<ExecuteStepRequest, ESR>, callback: sUD<ESR>): void;
    finishStepExecution(call: SUC<STEER, ESR>, callback: sUD<ESR>): void;
    finishScenarioExecution(call: SUC<SCEER, ESR>, callback: sUD<ESR>): void;
    finishSpecExecution(call: SUC<SPEER, ESR>, callback: sUD<ESR>): void;
    finishExecution(call: SUC<ExecutionEndingRequest, ESR>, callback: sUD<ESR>): void;
    cacheFile(call: SUC<CacheFileRequest, Empty>, callback: sUD<Empty>): void;
    getStepName(call: SUC<StepNameRequest, StepNameResponse>, callback: sUD<StepNameResponse>): void;
    getGlobPatterns(call: SUC<Empty, IFGPR>, callback: sUD<IFGPR>): void;
    getStepNames(call: SUC<StepNamesRequest, StepNamesResponse>, callback: sUD<StepNamesResponse>): void;
    getStepPositions(call: SUC<StepPositionsRequest, StepPositionsResponse>, callback: sUD<StepPositionsResponse>): void;
    getImplementationFiles(call: SUC<Empty, IFLR>, callback: sUD<IFLR>): void;
    implementStub(call: SUC<StubImplementationCodeRequest, FileDiff>, callback: sUD<FileDiff>): void;
    refactor(call: SUC<RefactorRequest, RefactorResponse>, callback: sUD<RefactorResponse>): void;
    kill(_call: SUC<KillProcessRequest, Empty>, callback: sUD<Empty>): void;
    private createRpcError;
    private getEmptExecutionResponse;
}
