"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepExecutionProcessor = void 0;
const spec_pb_1 = require("../gen/spec_pb");
const StepRegistry_1 = require("../models/StepRegistry");
const Screenshot_1 = require("../screenshot/Screenshot");
const MessageStore_1 = require("../stores/MessageStore");
const ScreenshotStore_1 = require("../stores/ScreenshotStore");
const ExecutionProcessor_1 = require("./ExecutionProcessor");
const Table_1 = require("../public/Table");
class StepExecutionProcessor extends ExecutionProcessor_1.ExecutionProcessor {
    process(req) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!StepRegistry_1.default.isImplemented(req.getParsedsteptext())) {
                return Promise.resolve(this.executionError("Step Implementation not found"));
            }
            const result = yield this.execute(req);
            return this.createExecutionResponse(result);
        });
    }
    execute(req) {
        return __awaiter(this, void 0, void 0, function* () {
            var _a;
            const start = Date.now();
            const result = new spec_pb_1.ProtoExecutionResult();
            result.setFailed(false);
            const mi = StepRegistry_1.default.get(req.getParsedsteptext());
            const params = req.getParametersList().map((item) => {
                return this.isTable(item) ? Table_1.Table.from(item.getTable()) : item.getValue();
            });
            const method = mi.getMethod();
            try {
                if (method.length !== params.length) {
                    throw new Error(`Argument length mismatch for \`${req.getActualsteptext()}\`.` +
                        ` Actual Count: [${method.length}], Expected Count: [${params.length}]`);
                }
                yield this.executeMethod(mi.getInstance(), method, params);
            }
            catch (err) {
                const error = err;
                result.setFailed(true);
                const cofErrors = StepRegistry_1.default.getContinueOnFailureFunctions(method);
                if (cofErrors && cofErrors.includes(error.constructor.name)) {
                    result.setRecoverableerror(true);
                }
                result.setErrormessage(error.message);
                result.setStacktrace((_a = error.stack) !== null && _a !== void 0 ? _a : '');
                if (process.env.screenshot_on_failure !== "false") {
                    const s = yield Screenshot_1.Screenshot.capture();
                    result.setFailurescreenshotfile(s);
                }
            }
            result.setExecutiontime(Date.now() - start);
            result.setMessageList(MessageStore_1.MessageStore.pendingMessages());
            result.setScreenshotfilesList(ScreenshotStore_1.ScreenshotStore.pendingScreenshots());
            return result;
        });
    }
    isTable(item) {
        return item.getParametertype() === spec_pb_1.Parameter.ParameterType.TABLE ||
            item.getParametertype() === spec_pb_1.Parameter.ParameterType.SPECIAL_TABLE;
    }
    executionError(message) {
        const result = new spec_pb_1.ProtoExecutionResult();
        result.setFailed(true);
        result.setRecoverableerror(false);
        result.setExecutiontime(0);
        result.setErrormessage(message);
        return this.createExecutionResponse(result);
    }
}
exports.StepExecutionProcessor = StepExecutionProcessor;
